# Drupal\helper\Config  

Provides helper for working with configuration.





## Methods

| Name | Description |
|------|-------------|
|[__construct](#config__construct)|Config constructor.|
|[create](#configcreate)|Creates a configuration.|
|[exists](#configexists)|Checks if a configuration exists or not.|
|[exportFile](#configexportfile)|Export a single configuration file.|
|[getData](#configgetdata)|Get the config data.|
|[importDirectory](#configimportdirectory)|Import a directory containing configuration files.|
|[importFile](#configimportfile)|Import a single configuration file.|
|[importModule](#configimportmodule)|Import a module's directory containing configuration files.|
|[load](#configload)|Load a configuration.|
|[reExportDirectory](#configreexportdirectory)|Re-export a directory containing configuration files.|
|[reExportModule](#configreexportmodule)|Import a module's directory containing configuration files.|
|[skipExisting](#configskipexisting)|Skip config imports if existing configuration already exists.|
|[updateExisting](#configupdateexisting)|Sets a flag to update existing configuration when importing the same file.|




### Config::__construct  

**Description**

```php
public __construct (\Drupal\Core\Config\ConfigFactoryInterface $config_factory, \Drupal\Core\Config\ConfigManagerInterface $config_manager, \Psr\Log\LoggerInterface $logger, \Drupal\Core\File\FileSystemInterface $file_system, \Drupal\Core\Extension\ModuleExtensionList $module_list)
```

Config constructor. 

 

**Parameters**

* `(\Drupal\Core\Config\ConfigFactoryInterface) $config_factory`
* `(\Drupal\Core\Config\ConfigManagerInterface) $config_manager`
* `(\Psr\Log\LoggerInterface) $logger`
* `(\Drupal\Core\File\FileSystemInterface) $file_system`
* `(\Drupal\Core\Extension\ModuleExtensionList) $module_list`

**Return Values**

`void`


<hr />


### Config::create  

**Description**

```php
public create (string $config_name, array $data)
```

Creates a configuration. 

This works for both simple config and configuration entities. 

**Parameters**

* `(string) $config_name`
* `(array) $data`

**Return Values**

`\Drupal\Core\Config\Entity\ConfigEntityInterface|\Drupal\Core\Config\Config`




<hr />


### Config::exists  

**Description**

```php
public exists (string $config_name)
```

Checks if a configuration exists or not. 

This works for both simple config and configuration entities. 

**Parameters**

* `(string) $config_name`

**Return Values**

`bool`




<hr />


### Config::exportFile  

**Description**

```php
public exportFile (string $config_name, string $directory, array $options)
```

Export a single configuration file. 

 

**Parameters**

* `(string) $config_name`
* `(string) $directory`
* `(array) $options`

**Return Values**

`void`


**Throws Exceptions**


`\RuntimeException`
> If the directory is not writeable or if the configuration does not exist.

<hr />


### Config::getData  

**Description**

```php
public getData (\Drupal\Core\Config\Entity\ConfigEntityInterface|\Drupal\Core\Config\Config $config)
```

Get the config data. 

 

**Parameters**

* `(\Drupal\Core\Config\Entity\ConfigEntityInterface|\Drupal\Core\Config\Config) $config`

**Return Values**

`array`




<hr />


### Config::importDirectory  

**Description**

```php
public importDirectory (string $directory, array $options)
```

Import a directory containing configuration files. 

 

**Parameters**

* `(string) $directory`
* `(array) $options`

**Return Values**

`void`


**Throws Exceptions**


`\RuntimeException`
> If unable to decode YAML from file.

`\Drupal\Core\Entity\EntityStorageException`
> In unable to save the config.

<hr />


### Config::importFile  

**Description**

```php
public importFile (string $uri, string $contents)
```

Import a single configuration file. 

 

**Parameters**

* `(string) $uri`
* `(string) $contents`

**Return Values**

`void`


**Throws Exceptions**


`\RuntimeException`
> If unable to decode YAML from file.

`\Drupal\Core\Entity\EntityStorageException`
> In unable to save the config.

<hr />


### Config::importModule  

**Description**

```php
public importModule (string $module, string $directory, array $options)
```

Import a module's directory containing configuration files. 

 

**Parameters**

* `(string) $module`
* `(string) $directory`
* `(array) $options`

**Return Values**

`void`


**Throws Exceptions**


`\RuntimeException`
> If unable to decode YAML from file.

`\Drupal\Core\Entity\EntityStorageException`
> In unable to save the config.

<hr />


### Config::load  

**Description**

```php
public load (string $config_name, bool $create)
```

Load a configuration. 

This works for both simple config and configuration entities. 

**Parameters**

* `(string) $config_name`
* `(bool) $create`

**Return Values**

`\Drupal\Core\Config\Entity\ConfigEntityInterface|\Drupal\Core\Config\Config|null`




<hr />


### Config::reExportDirectory  

**Description**

```php
public reExportDirectory (string $directory, array $options)
```

Re-export a directory containing configuration files. 

 

**Parameters**

* `(string) $directory`
* `(array) $options`

**Return Values**

`void`


**Throws Exceptions**


`\RuntimeException`
> If the directory is not writeable or if the configuration does not exist.

<hr />


### Config::reExportModule  

**Description**

```php
public reExportModule (string $module, string $directory, array $options)
```

Import a module's directory containing configuration files. 

 

**Parameters**

* `(string) $module`
* `(string) $directory`
* `(array) $options`

**Return Values**

`void`


**Throws Exceptions**


`\RuntimeException`
> If the directory is not writeable or if the configuration does not exist.

<hr />


### Config::skipExisting  

**Description**

```php
public skipExisting (void)
```

Skip config imports if existing configuration already exists. 

 

**Parameters**

`This function has no parameters.`

**Return Values**

`static`




<hr />


### Config::updateExisting  

**Description**

```php
public updateExisting (bool $update)
```

Sets a flag to update existing configuration when importing the same file. 

 

**Parameters**

* `(bool) $update`

**Return Values**

`static`




<hr />

