# Drupal\helper\InstallProfile  

Helpers related to working with install profiles.





## Methods

| Name | Description |
|------|-------------|
|[__construct](#installprofile__construct)|InstallProfileSwitcher constructor.|
|[switch](#installprofileswitch)|Switches the site's install profile.|
|[validateProfile](#installprofilevalidateprofile)|Validates a profile and checks its various requirements.|




### InstallProfile::__construct  

**Description**

```php
public __construct (\Drupal\Core\Extension\ExtensionList $profileList, \Drupal\Core\Config\ConfigFactoryInterface $configFactory, \Drupal\Core\Extension\ModuleHandlerInterface $module_handler, \Drupal\Core\KeyValueStore\KeyValueFactoryInterface $key_value_factory, \Drupal\Core\Update\UpdateHookRegistry $update_hook_registry)
```

InstallProfileSwitcher constructor. 

 

**Parameters**

* `(\Drupal\Core\Extension\ExtensionList) $profileList`
* `(\Drupal\Core\Config\ConfigFactoryInterface) $configFactory`
* `(\Drupal\Core\Extension\ModuleHandlerInterface) $module_handler`
* `(\Drupal\Core\KeyValueStore\KeyValueFactoryInterface) $key_value_factory`
* `(\Drupal\Core\Update\UpdateHookRegistry) $update_hook_registry`

**Return Values**

`void`


<hr />


### InstallProfile::switch  

**Description**

```php
public switch (string $profile, int $schema_version)
```

Switches the site's install profile. 

Note the following:  
- This does not run the new profile's install hooks.  
- Does not enable any of the profile's dependencies.  
- This does not check that currently enabled modules are located in the  
  current profile's code and will no longer be available once switching  
  to the new profile.  
- Does not run any uninstallation of the current profile, like removing  
  any tables defined in hook_schema(). 

**Parameters**

* `(string) $profile`
* `(int) $schema_version`

**Return Values**

`void`


<hr />


### InstallProfile::validateProfile  

**Description**

```php
public validateProfile (string $profile)
```

Validates a profile and checks its various requirements. 

This method performs the following validations:  
- Does the profile exist?  
- Does the profile have all of its module dependencies currently enabled?  
- Does the profile or any of its dependencies fail any hook_requirements()  
  checks with errors?  
- Does the current profile have any enabled modules or themes inside of it  
  that will go "missing" when switching to the new profile? 

**Parameters**

* `(string) $profile`

**Return Values**

`void`


**Throws Exceptions**


`\InvalidArgumentException`
> If the profile does not exist.

`\Drupal\Core\Installer\Exception\InstallerException`
> If the profile failed any validations.

<hr />

