# Drupal\helper\RenderElement  

Utility helpers for working with render elements.





## Methods

| Name | Description |
|------|-------------|
|[applyToChildren](#renderelementapplytochildren)|Apply a callback to the render element children.|
|[attachDrupalSetting](#renderelementattachdrupalsetting)|Attach a single drupalSettings key/value.|
|[attachDrupalSettings](#renderelementattachdrupalsettings)|Attach multiple drupalSettings|
|[attachFeed](#renderelementattachfeed)|Attach a feed.|
|[attachHeadLink](#renderelementattachheadlink)|Attach a head link.|
|[attachHeader](#renderelementattachheader)|Attach a HTML header.|
|[attachLibrary](#renderelementattachlibrary)|Attach library|
|[mergeAccess](#renderelementmergeaccess)|Change the access of a render element.|
|[wrap](#renderelementwrap)|Add a wrapper around a render element.|




### RenderElement::applyToChildren  

**Description**

```php
public static applyToChildren (array $element, callable $callback, mixed $args)
```

Apply a callback to the render element children. 

 

**Parameters**

* `(array) $element`
* `(callable) $callback`
* `(mixed) $args`

**Return Values**

`void`


<hr />


### RenderElement::attachDrupalSetting  

**Description**

```php
public static attachDrupalSetting (array $element, string $key, mixed $value)
```

Attach a single drupalSettings key/value. 

 

**Parameters**

* `(array) $element`
* `(string) $key`
* `(mixed) $value`

**Return Values**

`void`


<hr />


### RenderElement::attachDrupalSettings  

**Description**

```php
public static attachDrupalSettings (array $element, array $settings)
```

Attach multiple drupalSettings 

 

**Parameters**

* `(array) $element`
* `(array) $settings`

**Return Values**

`void`


<hr />


### RenderElement::attachFeed  

**Description**

```php
public static attachFeed (array $element, string $href, string|null $title)
```

Attach a feed. 

 

**Parameters**

* `(array) $element`
* `(string) $href`
* `(string|null) $title`

**Return Values**

`void`


<hr />


### RenderElement::attachHeadLink  

**Description**

```php
public static attachHeadLink (string $href, string $rel, array $attributes, bool $shouldAddHeader)
```

Attach a head link. 

 

**Parameters**

* `(string) $href`
* `(string) $rel`
* `(array) $attributes`
* `(bool) $shouldAddHeader`

**Return Values**

`void`


<hr />


### RenderElement::attachHeader  

**Description**

```php
public static attachHeader (array $element, string $name, string $value, bool $replace)
```

Attach a HTML header. 

 

**Parameters**

* `(array) $element`
* `(string) $name`
* `(string) $value`
* `(bool) $replace`

**Return Values**

`void`


<hr />


### RenderElement::attachLibrary  

**Description**

```php
public static attachLibrary (array $element, string $library)
```

Attach library 

 

**Parameters**

* `(array) $element`
* `(string) $library`

**Return Values**

`void`


<hr />


### RenderElement::mergeAccess  

**Description**

```php
public static mergeAccess (array $element, bool|\Drupal\Core\Access\AccessResultInterface $access, bool $and)
```

Change the access of a render element. 

 

**Parameters**

* `(array) $element`
* `(bool|\Drupal\Core\Access\AccessResultInterface) $access`
* `(bool) $and`

**Return Values**

`void`


<hr />


### RenderElement::wrap  

**Description**

```php
public static wrap (array $element, string|\Drupal\Component\Render\MarkupInterface $prefix, string|\Drupal\Component\Render\MarkupInterface $suffix, bool $inside)
```

Add a wrapper around a render element. 

 

**Parameters**

* `(array) $element`
* `(string|\Drupal\Component\Render\MarkupInterface) $prefix`
* `(string|\Drupal\Component\Render\MarkupInterface) $suffix`
* `(bool) $inside`

**Return Values**

`void`


<hr />

